@@ -41,7 +41,6 @@ pub struct DashInfo {
 
 ///
 /// Information on the properties of all the interval ticks for one dimension.
-/// Used by [`TickDist`]
 ///
 #[derive(Debug, Clone)]
 pub struct TickInfo<I> {
@@ -56,35 +55,6 @@ pub struct TickInfo<I> {
     pub dash_size: Option<f64>,
 }
 
-///
-/// A distribution of ticks. What [`crate::DataResult::plot_with`] accepts.
-///
-pub struct TickDist<J: TickFormat> {
-    pub ticks: TickInfo<J::Num>,
-    pub fmt: J,
-}
-
-impl<J: TickFormat> TickDist<J> {
-    pub fn with_tick_fmt<F>(self, func: F) -> TickDist<TickFmt<J, F>>
-    where
-        Self: Sized,
-        F: Fn(&mut dyn std::fmt::Write, &J::Num) -> std::fmt::Result,
-    {
-        TickDist {
-            ticks: self.ticks,
-            fmt: TickFmt {
-                inner: self.fmt,
-                func,
-            },
-        }
-    }
-
-    pub fn with_no_dash(mut self) -> Self {
-        self.ticks.dash_size = None;
-        self
-    }
-}
-
 ///
 /// Trait to allow a plotnum to have a default tick distribution.
 ///
@@ -92,7 +62,7 @@ impl<J: TickFormat> TickDist<J> {
 ///
 pub trait HasDefaultTicks: PlotNum {
     type Fmt: TickFormat<Num = Self>;
-    fn generate(bound: crate::Bound<Self>) -> TickDist<Self::Fmt>;
+    fn generate(bound: crate::Bound<Self>) -> (TickInfo<Self>, Self::Fmt);
 }
 
 #[derive(Debug, Copy, Clone)]
@@ -105,7 +75,7 @@ pub enum Axis {
 /// Formatter for a tick.
 ///
 pub trait TickFormat {
-    type Num;
+    type Num: PlotNum;
     fn write_tick(&mut self, a: &mut dyn std::fmt::Write, val: &Self::Num) -> std::fmt::Result;
     fn write_where(&mut self, _: &mut dyn std::fmt::Write) -> std::fmt::Result {
         Ok(())
@@ -165,3 +135,19 @@ impl<T: TickFormat, F: Fn(&mut dyn std::fmt::Write, &T::Num) -> std::fmt::Result
         self.inner.write_where(a)
     }
 }
+
+use std::fmt;
+///
+/// Used by [`crate::DataResult::plot_with`]
+///
+pub trait PlotFmt {
+    type X: PlotNum;
+    type Y: PlotNum;
+    fn write_title(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
+    fn write_xname(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
+    fn write_yname(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
+    fn write_xwher(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
+    fn write_ywher(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
+    fn write_xtick(&mut self, writer: &mut dyn fmt::Write, val: &Self::X) -> fmt::Result;
+    fn write_ytick(&mut self, writer: &mut dyn fmt::Write, val: &Self::Y) -> fmt::Result;
+}
