@@ -26,9 +26,6 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
     let xtick_info = &mut plotter.tickx;
     let ytick_info = &mut plotter.ticky;
 
-    let xcontext = &mut *plotter.xcontext;
-    let ycontext = &mut *plotter.ycontext;
-
     let texty_padding = paddingy * 0.3;
     let textx_padding = padding * 0.1;
 
@@ -41,10 +38,7 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
             d.attr("x", width / 2.0)?;
             d.attr("y", padding / 4.0)
         })?
-        .build(|w| {
-            use std::fmt::Write;
-            write!(w.writer_safe(), "{}", plotter.title)
-        })?;
+        .build(|w| plotter.plot_fmt.write_title(&mut w.writer_safe()))?;
 
     writer
         .elem("text", |d| {
@@ -55,10 +49,7 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
             d.attr("x", width / 2.0)?;
             d.attr("y", height - padding / 8.)
         })?
-        .build(|w| {
-            use std::fmt::Write;
-            write!(w.writer_safe(), "{}", plotter.xname)
-        })?;
+        .build(|w| plotter.plot_fmt.write_xname(&mut w.writer_safe()))?;
 
     writer
         .elem("text", |d| {
@@ -73,10 +64,7 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
             d.attr("x", padding / 4.0)?;
             d.attr("y", height / 2.0)
         })?
-        .build(|w| {
-            use std::fmt::Write;
-            write!(w.writer_safe(), "{}", plotter.yname)
-        })?;
+        .build(|w| plotter.plot_fmt.write_yname(&mut w.writer_safe()))?;
 
     let xdash_size = xtick_info.dash_size;
     let ydash_size = ytick_info.dash_size;
@@ -97,10 +85,7 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
                 d.attr("x", width * 0.55)?;
                 d.attr("y", paddingy * 0.7)
             })?
-            .build(|d| {
-                let mut w = d.writer_safe();
-                xcontext.write_where(&mut w)
-            })?;
+            .build(|d| plotter.plot_fmt.write_xwher(&mut d.writer_safe()))?;
 
         //Draw interva`l x text
         for &val in xtick_info.ticks.iter() {
@@ -123,11 +108,7 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
                     d.attr("x", aspect_offset + xx)?;
                     d.attr("y", height - paddingy + texty_padding)
                 })?
-                .build(|w| {
-                    let mut w = w.writer_safe();
-
-                    xcontext.write_tick(&mut w, &val)
-                })?;
+                .build(|w| plotter.plot_fmt.write_xtick(&mut w.writer_safe(), &val))?;
         }
     }
 
@@ -141,11 +122,7 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
                 d.attr("x", padding)?;
                 d.attr("y", paddingy * 0.7)
             })?
-            .build(|w| {
-                let mut w = w.writer_safe();
-
-                ycontext.write_where(&mut w)
-            })?;
+            .build(|w| plotter.plot_fmt.write_ywher(&mut w.writer_safe()))?;
 
         //Draw interval y text
         for &val in ytick_info.ticks.iter() {
@@ -170,10 +147,7 @@ pub fn render_base<X: PlotNum, Y: PlotNum>(
                     d.attr("x", aspect_offset + padding - textx_padding)?;
                     d.attr("y", yy)
                 })?
-                .build(|w| {
-                    let mut w = w.writer_safe();
-                    ycontext.write_tick(&mut w, &val)
-                })?;
+                .build(|w| plotter.plot_fmt.write_ytick(&mut w.writer_safe(), &val))?;
         }
     }
 
